//ICC-AVR application builder : 10.01.2010 23:21:36
// Target : T2313
// Crystal: 7.3728Mhz

#include <iot2313v.h>
#include <macros.h>


#pragma global_register sflag:20 cH:21 divt:22 High:23


//******************************************************************************	
#define TransmitterOn() \
	PORTD |= 0x40;   \

#define TransmitterOff() \
	PORTD &=~ 0x40;   \
//******************************************************************************	


unsigned char sflag, cH, divt, High;


void port_init(void)
{
 PORTA = 0x07;
 DDRA  = 0x00; 
 PORTB = 0x7F;
 DDRB  = 0xBC; 
 PORTD = 0x3F;
 DDRD  = 0x71; 
}

//UART0 initialize
// desired baud rate: 38400
// actual: baud rate:38462 (0,2%)
void uart0_init(void)
{
 UCSRB = 0x00; //disable while setting baud rate
 UBRRH = 0x00; //set baud rate upper
 UBRRL = 0x0C; //set baud rate lower
 UCSRA = 0x00;
 UCSRC = 0x06;
 UCSRB = 0xD8; //enable
}

#pragma interrupt_handler uart0_rx_isr:8
void uart0_rx_isr(void)
{
 //uart has received a character in UDR
}

#pragma interrupt_handler uart0_tx_isr:10
void uart0_tx_isr(void)
{
 //character has been transmitted
 TransmitterOff();
}


#pragma interrupt_handler int0_isr:2
void int0_isr(void)
{
 //external interupt on INT0
 TransmitterOn();
 UDR = 0x55;
}

//call this routine to initialize all peripherals
void init_devices(void)
{
 //stop errant interrupts until set up
 CLI(); //disable all interrupts
 port_init();
 uart0_init();

 MCUCR = 0x02;
 GIMSK = 0x40;
 TIMSK = 0x00;
 SEI(); //re-enable interrupts
 //all peripherals are now initialized
}


#pragma ctask transfer_spi
unsigned char transfer_spi(unsigned char c)
{
 USIDR = c;

// USISR = (1<<USIOIF);
 asm("ldi R16,64\n");
 asm("out 0xe,R16\n");
 
// USICR = (1<<USIWM0)|(0<<USICS1);
 asm("ldi R16,16\n");
 asm("out 0xd,R16\n");
 
// USICR = (1<<USIWM0)|(0<<USICS1)|(0<<USICS0)|(1<<USITC);
// USICR = (1<<USIWM0)|(0<<USICS1)|(0<<USICS0)|(1<<USITC)|(1<<USICLK); 
 asm("ldi R16,17\n");
 asm("ldi R21,19\n");
 asm("out 0xd,R16\n");
 asm("out 0xd,R21\n");
 asm("out 0xd,R16\n");
 asm("out 0xd,R21\n");
 asm("out 0xd,R16\n");
 asm("out 0xd,R21\n");
 asm("out 0xd,R16\n");
 asm("out 0xd,R21\n");
 asm("out 0xd,R16\n");
 asm("out 0xd,R21\n");
 asm("out 0xd,R16\n");
 asm("out 0xd,R21\n");
 asm("out 0xd,R16\n");
 asm("out 0xd,R21\n");
 asm("out 0xd,R16\n");
 asm("out 0xd,R21\n");
 
 return(USIDR);
}


void main(void)
{
 init_devices();
 
 transfer_spi(0xAA);
 
 do
 {
 }while(1);
}